@@ -1,5 +1,5 @@
 /* ************************************************************************
- * Copyright (C) 2016-2024 Advanced Micro Devices, Inc. All rights reserved.
+ * Copyright (C) 2016-2025 Advanced Micro Devices, Inc. All rights reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -30,8 +30,17 @@
 
 /* ============================================================================================ */
 
-using hipblasTrsmModel
-    = ArgumentModel<e_a_type, e_side, e_uplo, e_transA, e_diag, e_M, e_N, e_alpha, e_lda, e_ldb>;
+using hipblasTrsmModel = ArgumentModel<e_a_type,
+                                       e_side,
+                                       e_uplo,
+                                       e_transA,
+                                       e_diag,
+                                       e_M,
+                                       e_N,
+                                       e_alpha,
+                                       e_lda,
+                                       e_ldb,
+                                       e_user_allocated_workspace>;
 
 inline void testname_trsm(const Arguments& arg, std::string& name)
 {
@@ -41,6 +50,7 @@ inline void testname_trsm(const Arguments& arg, std::string& name)
 template <typename T>
 void testing_trsm_bad_arg(const Arguments& arg)
 {
+    using Ts           = hipblas_internal_type<T>;
     auto hipblasTrsmFn = arg.api == FORTRAN ? hipblasTrsm<T, true> : hipblasTrsm<T, false>;
     auto hipblasTrsmFn_64
         = arg.api == FORTRAN_64 ? hipblasTrsm_64<T, true> : hipblasTrsm_64<T, false>;
@@ -63,10 +73,10 @@ void testing_trsm_bad_arg(const Arguments& arg)
     device_matrix<T> dB(M, N, ldb);
 
     device_vector<T> d_alpha(1), d_zero(1);
-    const T          h_alpha(1), h_zero(0);
+    const Ts         h_alpha{1}, h_zero{0};
 
-    const T* alpha = &h_alpha;
-    const T* zero  = &h_zero;
+    const Ts* alpha = &h_alpha;
+    const Ts* zero  = &h_zero;
 
     for(auto pointer_mode : {HIPBLAS_POINTER_MODE_HOST, HIPBLAS_POINTER_MODE_DEVICE})
     {
@@ -190,6 +200,7 @@ void testing_trsm_bad_arg(const Arguments& arg)
 template <typename T>
 void testing_trsm(const Arguments& arg)
 {
+    using Ts           = hipblas_internal_type<T>;
     auto hipblasTrsmFn = arg.api == FORTRAN ? hipblasTrsm<T, true> : hipblasTrsm<T, false>;
     auto hipblasTrsmFn_64
         = arg.api == FORTRAN_64 ? hipblasTrsm_64<T, true> : hipblasTrsm_64<T, false>;
@@ -271,7 +282,18 @@ void testing_trsm(const Arguments& arg)
     {
         CHECK_HIPBLAS_ERROR(hipblasSetPointerMode(handle, HIPBLAS_POINTER_MODE_HOST));
         DAPI_CHECK(hipblasTrsmFn,
-                   (handle, side, uplo, transA, diag, M, N, &h_alpha, dA, lda, dB, ldb));
+                   (handle,
+                    side,
+                    uplo,
+                    transA,
+                    diag,
+                    M,
+                    N,
+                    reinterpret_cast<Ts*>(&h_alpha),
+                    dA,
+                    lda,
+                    dB,
+                    ldb));
 
         CHECK_HIP_ERROR(hB_host.transfer_from(dB));
         CHECK_HIP_ERROR(dB.transfer_from(hB_device));
