@@ -1,5 +1,5 @@
 /* ************************************************************************
- * Copyright (C) 2016-2024 Advanced Micro Devices, Inc. All rights reserved.
+ * Copyright (C) 2016-2025 Advanced Micro Devices, Inc. All rights reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -46,15 +46,16 @@ inline void testname_scal_strided_batched_ex(const Arguments& arg, std::string&
 template <typename Ta, typename Tx = Ta, typename Tex = Tx>
 void testing_scal_strided_batched_ex_bad_arg(const Arguments& arg)
 {
+    using Ts = hipblas_internal_type<Ta>;
     auto hipblasScalStridedBatchedExFn
         = arg.api == FORTRAN ? hipblasScalStridedBatchedExFortran : hipblasScalStridedBatchedEx;
     auto hipblasScalStridedBatchedExFn_64 = arg.api == FORTRAN_64
                                                 ? hipblasScalStridedBatchedEx_64Fortran
                                                 : hipblasScalStridedBatchedEx_64;
 
-    hipblasDatatype_t alphaType     = arg.a_type;
-    hipblasDatatype_t xType         = arg.b_type;
-    hipblasDatatype_t executionType = arg.compute_type;
+    hipDataType alphaType     = arg.a_type;
+    hipDataType xType         = arg.b_type;
+    hipDataType executionType = arg.compute_type;
 
     int64_t N           = 100;
     int64_t incx        = 1;
@@ -130,6 +131,7 @@ void testing_scal_strided_batched_ex_bad_arg(const Arguments& arg)
 template <typename Ta, typename Tx = Ta, typename Tex = Tx>
 void testing_scal_strided_batched_ex(const Arguments& arg)
 {
+    using Ts = hipblas_internal_type<Ta>;
     auto hipblasScalStridedBatchedExFn
         = arg.api == FORTRAN ? hipblasScalStridedBatchedExFortran : hipblasScalStridedBatchedEx;
     auto hipblasScalStridedBatchedExFn_64 = arg.api == FORTRAN_64
@@ -152,9 +154,9 @@ void testing_scal_strided_batched_ex(const Arguments& arg)
 
     hipblasLocalHandle handle(arg);
 
-    hipblasDatatype_t alphaType     = arg.a_type;
-    hipblasDatatype_t xType         = arg.b_type;
-    hipblasDatatype_t executionType = arg.compute_type;
+    hipDataType alphaType     = arg.a_type;
+    hipDataType xType         = arg.b_type;
+    hipDataType executionType = arg.compute_type;
 
     // argument sanity check, quick return if input parameters are invalid before allocating invalid
     // memory
@@ -208,9 +210,17 @@ void testing_scal_strided_batched_ex(const Arguments& arg)
             HIPBLAS
         =================================================================== */
         CHECK_HIPBLAS_ERROR(hipblasSetPointerMode(handle, HIPBLAS_POINTER_MODE_HOST));
-        DAPI_CHECK(
-            hipblasScalStridedBatchedExFn,
-            (handle, N, &h_alpha, alphaType, dx, xType, incx, stridex, batch_count, executionType));
+        DAPI_CHECK(hipblasScalStridedBatchedExFn,
+                   (handle,
+                    N,
+                    reinterpret_cast<Ts*>(&h_alpha),
+                    alphaType,
+                    dx,
+                    xType,
+                    incx,
+                    stridex,
+                    batch_count,
+                    executionType));
 
         // copy output from device to CPU
         CHECK_HIP_ERROR(hx_host.transfer_from(dx));
