@@ -1,5 +1,5 @@
 /* ************************************************************************
- * Copyright (C) 2016-2024 Advanced Micro Devices, Inc. All rights reserved.
+ * Copyright (C) 2016-2025 Advanced Micro Devices, Inc. All rights reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -52,6 +52,7 @@ inline void testname_trsm_batched_ex(const Arguments& arg, std::string& name)
 template <typename T>
 void testing_trsm_batched_ex_bad_arg(const Arguments& arg)
 {
+    using Ts                    = hipblas_internal_type<T>;
     bool FORTRAN                = arg.api == hipblas_client_api::FORTRAN;
     auto hipblasTrsmBatchedExFn = FORTRAN ? hipblasTrsmBatchedExFortran : hipblasTrsmBatchedEx;
 
@@ -66,20 +67,21 @@ void testing_trsm_batched_ex_bad_arg(const Arguments& arg)
     hipblasFillMode_t  uplo        = HIPBLAS_FILL_MODE_LOWER;
     hipblasOperation_t transA      = HIPBLAS_OP_N;
     hipblasDiagType_t  diag        = HIPBLAS_DIAG_NON_UNIT;
-    hipblasDatatype_t  computeType = arg.compute_type;
+    hipDataType        computeType = arg.compute_type;
 
     int64_t K        = side == HIPBLAS_SIDE_LEFT ? M : N;
     int64_t invAsize = TRSM_BLOCK * K;
 
-    device_batch_vector<T> dA(K * lda, 1, batch_count);
-    device_batch_vector<T> dB(N * ldb, 1, batch_count);
-    device_batch_vector<T> dInvA(invAsize, 1, batch_count);
+    // Allocate device memory
+    device_batch_matrix<T> dA(K, K, lda, batch_count);
+    device_batch_matrix<T> dB(M, N, ldb, batch_count);
+    device_batch_matrix<T> dinvA(TRSM_BLOCK, TRSM_BLOCK, K, batch_count);
 
     device_vector<T> d_alpha(1), d_zero(1);
-    const T          h_alpha(1), h_zero(0);
+    const Ts         h_alpha{1}, h_zero{0};
 
-    const T* alpha = &h_alpha;
-    const T* zero  = &h_zero;
+    const Ts* alpha = &h_alpha;
+    const Ts* zero  = &h_zero;
 
     for(auto pointer_mode : {HIPBLAS_POINTER_MODE_HOST, HIPBLAS_POINTER_MODE_DEVICE})
     {
@@ -106,7 +108,7 @@ void testing_trsm_batched_ex_bad_arg(const Arguments& arg)
                                                      dB.ptr_on_device(),
                                                      ldb,
                                                      batch_count,
-                                                     dInvA.ptr_on_device(),
+                                                     dinvA.ptr_on_device(),
                                                      invAsize,
                                                      computeType),
                               HIPBLAS_STATUS_NOT_INITIALIZED);
@@ -124,7 +126,7 @@ void testing_trsm_batched_ex_bad_arg(const Arguments& arg)
                                                      dB.ptr_on_device(),
                                                      ldb,
                                                      batch_count,
-                                                     dInvA.ptr_on_device(),
+                                                     dinvA.ptr_on_device(),
                                                      invAsize,
                                                      computeType),
                               HIPBLAS_STATUS_INVALID_VALUE);
@@ -142,7 +144,7 @@ void testing_trsm_batched_ex_bad_arg(const Arguments& arg)
                                                      dB.ptr_on_device(),
                                                      ldb,
                                                      batch_count,
-                                                     dInvA.ptr_on_device(),
+                                                     dinvA.ptr_on_device(),
                                                      invAsize,
                                                      computeType),
                               HIPBLAS_STATUS_INVALID_VALUE);
@@ -159,7 +161,7 @@ void testing_trsm_batched_ex_bad_arg(const Arguments& arg)
                                                      dB.ptr_on_device(),
                                                      ldb,
                                                      batch_count,
-                                                     dInvA.ptr_on_device(),
+                                                     dinvA.ptr_on_device(),
                                                      invAsize,
                                                      computeType),
                               HIPBLAS_STATUS_INVALID_ENUM);
@@ -176,7 +178,7 @@ void testing_trsm_batched_ex_bad_arg(const Arguments& arg)
                                                      dB.ptr_on_device(),
                                                      ldb,
                                                      batch_count,
-                                                     dInvA.ptr_on_device(),
+                                                     dinvA.ptr_on_device(),
                                                      invAsize,
                                                      computeType),
                               HIPBLAS_STATUS_INVALID_ENUM);
@@ -194,9 +196,9 @@ void testing_trsm_batched_ex_bad_arg(const Arguments& arg)
                                                      dB.ptr_on_device(),
                                                      ldb,
                                                      batch_count,
-                                                     dInvA.ptr_on_device(),
+                                                     dinvA.ptr_on_device(),
                                                      invAsize,
-                                                     HIPBLAS_R_16F),
+                                                     HIP_R_16F),
                               HIPBLAS_STATUS_NOT_SUPPORTED);
 
         EXPECT_HIPBLAS_STATUS(hipblasTrsmBatchedExFn(handle,
@@ -212,7 +214,7 @@ void testing_trsm_batched_ex_bad_arg(const Arguments& arg)
                                                      dB.ptr_on_device(),
                                                      ldb,
                                                      batch_count,
-                                                     dInvA.ptr_on_device(),
+                                                     dinvA.ptr_on_device(),
                                                      invAsize,
                                                      computeType),
                               HIPBLAS_STATUS_INVALID_VALUE);
@@ -232,7 +234,7 @@ void testing_trsm_batched_ex_bad_arg(const Arguments& arg)
                                                          dB.ptr_on_device(),
                                                          ldb,
                                                          batch_count,
-                                                         dInvA.ptr_on_device(),
+                                                         dinvA.ptr_on_device(),
                                                          invAsize,
                                                          computeType),
                                   HIPBLAS_STATUS_INVALID_VALUE);
@@ -249,7 +251,7 @@ void testing_trsm_batched_ex_bad_arg(const Arguments& arg)
                                                          nullptr,
                                                          ldb,
                                                          batch_count,
-                                                         dInvA.ptr_on_device(),
+                                                         dinvA.ptr_on_device(),
                                                          invAsize,
                                                          computeType),
                                   HIPBLAS_STATUS_INVALID_VALUE);
@@ -269,7 +271,7 @@ void testing_trsm_batched_ex_bad_arg(const Arguments& arg)
                                                    dB.ptr_on_device(),
                                                    ldb,
                                                    batch_count,
-                                                   dInvA.ptr_on_device(),
+                                                   dinvA.ptr_on_device(),
                                                    invAsize,
                                                    computeType));
 
@@ -345,6 +347,7 @@ void testing_trsm_batched_ex_bad_arg(const Arguments& arg)
 template <typename T>
 void testing_trsm_batched_ex(const Arguments& arg)
 {
+    using Ts                    = hipblas_internal_type<T>;
     bool FORTRAN                = arg.api == hipblas_client_api::FORTRAN;
     auto hipblasTrsmBatchedExFn = FORTRAN ? hipblasTrsmBatchedExFortran : hipblasTrsmBatchedEx;
 
@@ -360,9 +363,7 @@ void testing_trsm_batched_ex(const Arguments& arg)
 
     T h_alpha = arg.get_alpha<T>();
 
-    int    K      = (side == HIPBLAS_SIDE_LEFT ? M : N);
-    size_t A_size = size_t(lda) * K;
-    size_t B_size = size_t(ldb) * N;
+    int K = (side == HIPBLAS_SIDE_LEFT ? M : N);
 
     // check here to prevent undefined memory allocation error
     // TODO: Workaround for cuda tests, not actually testing return values
@@ -374,44 +375,46 @@ void testing_trsm_batched_ex(const Arguments& arg)
     {
         return;
     }
-    // Naming: dK is in GPU (device) memory. hK is in CPU (host) memory
-    host_batch_vector<T> hA(A_size, 1, batch_count);
-    host_batch_vector<T> hB_host(B_size, 1, batch_count);
-    host_batch_vector<T> hB_device(B_size, 1, batch_count);
-    host_batch_vector<T> hB_cpu(B_size, 1, batch_count);
+    // Naming: `h` is in CPU (host) memory(eg hA), `d` is in GPU (device) memory (eg dA).
+    // Allocate host memory
+    host_batch_matrix<T> hA(K, K, lda, batch_count);
+    host_batch_matrix<T> hB_host(M, N, ldb, batch_count);
+    host_batch_matrix<T> hB_device(M, N, ldb, batch_count);
+    host_batch_matrix<T> hB_cpu(M, N, ldb, batch_count);
 
-    device_batch_vector<T> dA(A_size, 1, batch_count);
-    device_batch_vector<T> dB(B_size, 1, batch_count);
-    device_batch_vector<T> dinvA(TRSM_BLOCK * K, 1, batch_count);
+    // Check host memory allocation
+    CHECK_HIP_ERROR(hA.memcheck());
+    CHECK_HIP_ERROR(hB_host.memcheck());
+    CHECK_HIP_ERROR(hB_device.memcheck());
+    CHECK_HIP_ERROR(hB_cpu.memcheck());
+
+    // Allocate device memory
+    device_batch_matrix<T> dA(K, K, lda, batch_count);
+    device_batch_matrix<T> dB(M, N, ldb, batch_count);
+    device_batch_matrix<T> dinvA(TRSM_BLOCK, TRSM_BLOCK, K, batch_count);
     device_vector<T>       d_alpha(1);
 
-    CHECK_HIP_ERROR(dA.memcheck());
-    CHECK_HIP_ERROR(dB.memcheck());
-    CHECK_HIP_ERROR(dinvA.memcheck());
+    // Check device memory allocation
+    CHECK_DEVICE_ALLOCATION(dA.memcheck());
+    CHECK_DEVICE_ALLOCATION(dB.memcheck());
+    CHECK_DEVICE_ALLOCATION(dinvA.memcheck());
+    CHECK_DEVICE_ALLOCATION(d_alpha.memcheck());
 
     double             gpu_time_used, hipblas_error_host, hipblas_error_device;
     hipblasLocalHandle handle(arg);
 
-    // Initial hA on CPU
-    hipblas_init_vector(hB_host, arg, hipblas_client_never_set_nan);
+    // Initial data on CPU
+    hipblas_init_matrix(
+        hA, arg, hipblas_client_never_set_nan, hipblas_diagonally_dominant_triangular_matrix, true);
+    hipblas_init_matrix(hB_host, arg, hipblas_client_never_set_nan, hipblas_general_matrix);
+
+    if(diag == HIPBLAS_DIAG_UNIT)
+    {
+        make_unit_diagonal(uplo, hA);
+    }
+
     for(int b = 0; b < batch_count; b++)
     {
-        hipblas_init_matrix_type(hipblas_diagonally_dominant_triangular_matrix,
-                                 (T*)hA[b],
-                                 arg,
-                                 K,
-                                 K,
-                                 lda,
-                                 0,
-                                 1,
-                                 hipblas_client_never_set_nan,
-                                 true);
-
-        if(diag == HIPBLAS_DIAG_UNIT)
-        {
-            make_unit_diagonal(uplo, (T*)hA[b], lda, K);
-        }
-
         // Calculate hB = hA*hX;
         ref_trmm<T>(side,
                     uplo,
@@ -484,7 +487,7 @@ void testing_trsm_batched_ex(const Arguments& arg)
                                                    diag,
                                                    M,
                                                    N,
-                                                   &h_alpha,
+                                                   reinterpret_cast<Ts*>(&h_alpha),
                                                    dA.ptr_on_device(),
                                                    lda,
                                                    dB.ptr_on_device(),
