@@ -1,5 +1,5 @@
 /* ************************************************************************
- * Copyright (C) 2016-2024 Advanced Micro Devices, Inc. All rights reserved.
+ * Copyright (C) 2016-2025 Advanced Micro Devices, Inc. All rights reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -43,6 +43,7 @@ inline void testname_trsm_ex(const Arguments& arg, std::string& name)
 template <typename T>
 void testing_trsm_ex_bad_arg(const Arguments& arg)
 {
+    using Ts             = hipblas_internal_type<T>;
     bool FORTRAN         = arg.api == hipblas_client_api::FORTRAN;
     auto hipblasTrsmExFn = FORTRAN ? hipblasTrsmExFortran : hipblasTrsmEx;
 
@@ -56,20 +57,21 @@ void testing_trsm_ex_bad_arg(const Arguments& arg)
     hipblasFillMode_t  uplo        = HIPBLAS_FILL_MODE_LOWER;
     hipblasOperation_t transA      = HIPBLAS_OP_N;
     hipblasDiagType_t  diag        = HIPBLAS_DIAG_NON_UNIT;
-    hipblasDatatype_t  computeType = arg.compute_type;
+    hipDataType        computeType = arg.compute_type;
 
     int64_t K        = side == HIPBLAS_SIDE_LEFT ? M : N;
     int64_t invAsize = TRSM_BLOCK * K;
 
-    device_vector<T> dA(K * lda);
-    device_vector<T> dB(N * ldb);
-    device_vector<T> dInvA(invAsize);
+    // Allocate device memory
+    device_matrix<T> dA(K, K, lda);
+    device_matrix<T> dB(M, N, ldb);
+    device_vector<T> dinvA(TRSM_BLOCK, TRSM_BLOCK, K);
 
     device_vector<T> d_alpha(1), d_zero(1);
-    const T          h_alpha(1), h_zero(0);
+    const Ts         h_alpha{1}, h_zero{0};
 
-    const T* alpha = &h_alpha;
-    const T* zero  = &h_zero;
+    const Ts* alpha = &h_alpha;
+    const Ts* zero  = &h_zero;
 
     for(auto pointer_mode : {HIPBLAS_POINTER_MODE_HOST, HIPBLAS_POINTER_MODE_DEVICE})
     {
@@ -95,7 +97,7 @@ void testing_trsm_ex_bad_arg(const Arguments& arg)
                                               lda,
                                               dB,
                                               ldb,
-                                              dInvA,
+                                              dinvA,
                                               invAsize,
                                               computeType),
                               HIPBLAS_STATUS_NOT_INITIALIZED);
@@ -112,7 +114,7 @@ void testing_trsm_ex_bad_arg(const Arguments& arg)
                                               lda,
                                               dB,
                                               ldb,
-                                              dInvA,
+                                              dinvA,
                                               invAsize,
                                               computeType),
                               HIPBLAS_STATUS_INVALID_VALUE);
@@ -129,7 +131,7 @@ void testing_trsm_ex_bad_arg(const Arguments& arg)
                                               lda,
                                               dB,
                                               ldb,
-                                              dInvA,
+                                              dinvA,
                                               invAsize,
                                               computeType),
                               HIPBLAS_STATUS_INVALID_VALUE);
@@ -145,7 +147,7 @@ void testing_trsm_ex_bad_arg(const Arguments& arg)
                                               lda,
                                               dB,
                                               ldb,
-                                              dInvA,
+                                              dinvA,
                                               invAsize,
                                               computeType),
                               HIPBLAS_STATUS_INVALID_ENUM);
@@ -161,7 +163,7 @@ void testing_trsm_ex_bad_arg(const Arguments& arg)
                                               lda,
                                               dB,
                                               ldb,
-                                              dInvA,
+                                              dinvA,
                                               invAsize,
                                               computeType),
                               HIPBLAS_STATUS_INVALID_ENUM);
@@ -178,9 +180,9 @@ void testing_trsm_ex_bad_arg(const Arguments& arg)
                                               lda,
                                               dB,
                                               ldb,
-                                              dInvA,
+                                              dinvA,
                                               invAsize,
-                                              HIPBLAS_R_16F),
+                                              HIP_R_16F),
                               HIPBLAS_STATUS_NOT_SUPPORTED);
 
         EXPECT_HIPBLAS_STATUS(hipblasTrsmExFn(handle,
@@ -195,7 +197,7 @@ void testing_trsm_ex_bad_arg(const Arguments& arg)
                                               lda,
                                               dB,
                                               ldb,
-                                              dInvA,
+                                              dinvA,
                                               invAsize,
                                               computeType),
                               HIPBLAS_STATUS_INVALID_VALUE);
@@ -214,7 +216,7 @@ void testing_trsm_ex_bad_arg(const Arguments& arg)
                                                   lda,
                                                   dB,
                                                   ldb,
-                                                  dInvA,
+                                                  dinvA,
                                                   invAsize,
                                                   computeType),
                                   HIPBLAS_STATUS_INVALID_VALUE);
@@ -230,7 +232,7 @@ void testing_trsm_ex_bad_arg(const Arguments& arg)
                                                   lda,
                                                   nullptr,
                                                   ldb,
-                                                  dInvA,
+                                                  dinvA,
                                                   invAsize,
                                                   computeType),
                                   HIPBLAS_STATUS_INVALID_VALUE);
@@ -249,7 +251,7 @@ void testing_trsm_ex_bad_arg(const Arguments& arg)
                                             lda,
                                             dB,
                                             ldb,
-                                            dInvA,
+                                            dinvA,
                                             invAsize,
                                             computeType));
 
@@ -307,6 +309,7 @@ void testing_trsm_ex_bad_arg(const Arguments& arg)
 template <typename T>
 void testing_trsm_ex(const Arguments& arg)
 {
+    using Ts             = hipblas_internal_type<T>;
     bool FORTRAN         = arg.api == hipblas_client_api::FORTRAN;
     auto hipblasTrsmExFn = FORTRAN ? hipblasTrsmExFortran : hipblasTrsmEx;
 
@@ -321,41 +324,40 @@ void testing_trsm_ex(const Arguments& arg)
 
     T h_alpha = arg.get_alpha<T>();
 
-    int    K      = (side == HIPBLAS_SIDE_LEFT ? M : N);
-    size_t A_size = size_t(lda) * K;
-    size_t B_size = size_t(ldb) * N;
+    int K = (side == HIPBLAS_SIDE_LEFT ? M : N);
 
     // check here to prevent undefined memory allocation error
     if(M < 0 || N < 0 || lda < K || ldb < M)
     {
         return;
     }
-    // Naming: dK is in GPU (device) memory. hK is in CPU (host) memory
-    host_vector<T> hA(A_size);
-    host_vector<T> hB_host(B_size);
-    host_vector<T> hB_device(B_size);
-    host_vector<T> hB_cpu(B_size);
 
-    device_vector<T> dA(A_size);
-    device_vector<T> dB(B_size);
-    device_vector<T> dinvA(TRSM_BLOCK * K);
+    // Naming: `h` is in CPU (host) memory(eg hA), `d` is in GPU (device) memory (eg dA).
+    // Allocate host memory
+    host_matrix<T> hA(K, K, lda);
+    host_matrix<T> hB_host(K, K, ldb);
+    host_matrix<T> hB_device(M, N, ldb);
+    host_matrix<T> hB_cpu(M, N, ldb);
+
+    // Allocate device memory
+    device_matrix<T> dA(K, K, lda);
+    device_matrix<T> dB(M, N, ldb);
+    device_matrix<T> dinvA(TRSM_BLOCK, TRSM_BLOCK, K);
     device_vector<T> d_alpha(1);
 
+    // Check device memory allocation
+    CHECK_DEVICE_ALLOCATION(dA.memcheck());
+    CHECK_DEVICE_ALLOCATION(dB.memcheck());
+    CHECK_DEVICE_ALLOCATION(dinvA.memcheck());
+    CHECK_DEVICE_ALLOCATION(d_alpha.memcheck());
+
     double             gpu_time_used, hipblas_error_host, hipblas_error_device;
     hipblasLocalHandle handle(arg);
 
-    // Initial hA on CPU
-    hipblas_init_matrix_type(hipblas_diagonally_dominant_triangular_matrix,
-                             (T*)hA,
-                             arg,
-                             K,
-                             K,
-                             lda,
-                             0,
-                             1,
-                             hipblas_client_never_set_nan,
-                             true);
-    hipblas_init_matrix(hB_host, arg, M, N, ldb, 0, 1, hipblas_client_never_set_nan);
+    // Initial data on CPU
+    hipblas_init_matrix(
+        hA, arg, hipblas_client_never_set_nan, hipblas_diagonally_dominant_triangular_matrix, true);
+    hipblas_init_matrix(hB_host, arg, hipblas_client_never_set_nan, hipblas_general_matrix);
 
     if(diag == HIPBLAS_DIAG_UNIT)
     {
@@ -378,8 +380,8 @@ void testing_trsm_ex(const Arguments& arg)
     hB_cpu = hB_device = hB_host;
 
     // copy data from CPU to device
-    CHECK_HIP_ERROR(hipMemcpy(dA, hA, sizeof(T) * A_size, hipMemcpyHostToDevice));
-    CHECK_HIP_ERROR(hipMemcpy(dB, hB_host, sizeof(T) * B_size, hipMemcpyHostToDevice));
+    CHECK_HIP_ERROR(dA.transfer_from(hA));
+    CHECK_HIP_ERROR(dB.transfer_from(hB_host));
     CHECK_HIP_ERROR(hipMemcpy(d_alpha, &h_alpha, sizeof(T), hipMemcpyHostToDevice));
 
     hipblasStride stride_A    = TRSM_BLOCK * size_t(lda) + TRSM_BLOCK;
@@ -430,7 +432,7 @@ void testing_trsm_ex(const Arguments& arg)
                                             diag,
                                             M,
                                             N,
-                                            &h_alpha,
+                                            reinterpret_cast<Ts*>(&h_alpha),
                                             dA,
                                             lda,
                                             dB,
@@ -440,8 +442,8 @@ void testing_trsm_ex(const Arguments& arg)
                                             arg.compute_type));
 
         // copy output from device to CPU
-        CHECK_HIP_ERROR(hipMemcpy(hB_host, dB, sizeof(T) * B_size, hipMemcpyDeviceToHost));
-        CHECK_HIP_ERROR(hipMemcpy(dB, hB_device, sizeof(T) * B_size, hipMemcpyHostToDevice));
+        CHECK_HIP_ERROR(hB_host.transfer_from(dB));
+        CHECK_HIP_ERROR(dB.transfer_from(hB_device));
 
         CHECK_HIPBLAS_ERROR(hipblasSetPointerMode(handle, HIPBLAS_POINTER_MODE_DEVICE));
         CHECK_HIPBLAS_ERROR(hipblasTrsmExFn(handle,
@@ -460,7 +462,7 @@ void testing_trsm_ex(const Arguments& arg)
                                             TRSM_BLOCK * K,
                                             arg.compute_type));
 
-        CHECK_HIP_ERROR(hipMemcpy(hB_device, dB, sizeof(T) * B_size, hipMemcpyDeviceToHost));
+        CHECK_HIP_ERROR(hB_device.transfer_from(dB));
 
         /* =====================================================================
            CPU BLAS
