@@ -1,5 +1,5 @@
 /* ************************************************************************
- * Copyright (C) 2016-2023 Advanced Micro Devices, Inc. All rights reserved.
+ * Copyright (C) 2016-2024 Advanced Micro Devices, Inc. All rights reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -21,7 +21,6 @@
  *
  * ************************************************************************ */
 
-#include "gtest/gtest.h"
 #include <fstream>
 #include <iostream>
 #include <stdlib.h>
@@ -45,23 +44,23 @@ void testing_gels_strided_batched_bad_arg(const Arguments& arg)
                                            : hipblasGelsStridedBatched<T, false>;
 
     hipblasLocalHandle       handle(arg);
-    const int                M          = 100;
-    const int                N          = 101;
-    const int                nrhs       = 10;
-    const int                lda        = 102;
-    const int                ldb        = 103;
-    const int                batchCount = 2;
-    const hipblasOperation_t opN        = HIPBLAS_OP_N;
-    const hipblasOperation_t opBad      = is_complex<T> ? HIPBLAS_OP_T : HIPBLAS_OP_C;
+    const int                M           = 100;
+    const int                N           = 101;
+    const int                nrhs        = 10;
+    const int                lda         = 102;
+    const int                ldb         = 103;
+    const int                batch_count = 2;
+    const hipblasOperation_t opN         = HIPBLAS_OP_N;
+    const hipblasOperation_t opBad       = is_complex<T> ? HIPBLAS_OP_T : HIPBLAS_OP_C;
 
     const hipblasStride strideA = size_t(lda) * N;
     const hipblasStride strideB = size_t(ldb) * nrhs;
-    const size_t        A_size  = strideA * batchCount;
-    const size_t        B_size  = strideB * batchCount;
 
-    device_vector<T>   dA(A_size);
-    device_vector<T>   dB(B_size);
-    device_vector<int> dInfo(batchCount);
+    // Allocate device memory
+    device_strided_batch_matrix<T> dA(M, N, lda, strideA, batch_count);
+    device_strided_batch_matrix<T> dB(M, nrhs, ldb, strideB, batch_count);
+
+    device_vector<int> dInfo(batch_count);
     int                info = 0;
     int                expectedInfo;
 
@@ -78,7 +77,7 @@ void testing_gels_strided_batched_bad_arg(const Arguments& arg)
                                                       strideB,
                                                       nullptr,
                                                       dInfo,
-                                                      batchCount),
+                                                      batch_count),
                           HIPBLAS_STATUS_INVALID_VALUE);
 
     EXPECT_HIPBLAS_STATUS(hipblasGelsStridedBatchedFn(handle,
@@ -94,28 +93,50 @@ void testing_gels_strided_batched_bad_arg(const Arguments& arg)
                                                       strideB,
                                                       &info,
                                                       dInfo,
-                                                      batchCount),
+                                                      batch_count),
                           HIPBLAS_STATUS_INVALID_VALUE);
     expectedInfo = -1;
     unit_check_general(1, 1, 1, &expectedInfo, &info);
 
-    EXPECT_HIPBLAS_STATUS(
-        hipblasGelsStridedBatchedFn(
-            handle, opN, -1, N, nrhs, dA, lda, strideA, dB, ldb, strideB, &info, dInfo, batchCount),
-        HIPBLAS_STATUS_INVALID_VALUE);
+    EXPECT_HIPBLAS_STATUS(hipblasGelsStridedBatchedFn(handle,
+                                                      opN,
+                                                      -1,
+                                                      N,
+                                                      nrhs,
+                                                      dA,
+                                                      lda,
+                                                      strideA,
+                                                      dB,
+                                                      ldb,
+                                                      strideB,
+                                                      &info,
+                                                      dInfo,
+                                                      batch_count),
+                          HIPBLAS_STATUS_INVALID_VALUE);
     expectedInfo = -2;
     unit_check_general(1, 1, 1, &expectedInfo, &info);
 
-    EXPECT_HIPBLAS_STATUS(
-        hipblasGelsStridedBatchedFn(
-            handle, opN, M, -1, nrhs, dA, lda, strideA, dB, ldb, strideB, &info, dInfo, batchCount),
-        HIPBLAS_STATUS_INVALID_VALUE);
+    EXPECT_HIPBLAS_STATUS(hipblasGelsStridedBatchedFn(handle,
+                                                      opN,
+                                                      M,
+                                                      -1,
+                                                      nrhs,
+                                                      dA,
+                                                      lda,
+                                                      strideA,
+                                                      dB,
+                                                      ldb,
+                                                      strideB,
+                                                      &info,
+                                                      dInfo,
+                                                      batch_count),
+                          HIPBLAS_STATUS_INVALID_VALUE);
     expectedInfo = -3;
     unit_check_general(1, 1, 1, &expectedInfo, &info);
 
     EXPECT_HIPBLAS_STATUS(
         hipblasGelsStridedBatchedFn(
-            handle, opN, M, N, -1, dA, lda, strideA, dB, ldb, strideB, &info, dInfo, batchCount),
+            handle, opN, M, N, -1, dA, lda, strideA, dB, ldb, strideB, &info, dInfo, batch_count),
         HIPBLAS_STATUS_INVALID_VALUE);
     expectedInfo = -4;
     unit_check_general(1, 1, 1, &expectedInfo, &info);
@@ -133,7 +154,7 @@ void testing_gels_strided_batched_bad_arg(const Arguments& arg)
                                                       strideB,
                                                       &info,
                                                       dInfo,
-                                                      batchCount),
+                                                      batch_count),
                           HIPBLAS_STATUS_INVALID_VALUE);
     expectedInfo = -5;
     unit_check_general(1, 1, 1, &expectedInfo, &info);
@@ -150,7 +171,7 @@ void testing_gels_strided_batched_bad_arg(const Arguments& arg)
                                                       strideB,
                                                       &info,
                                                       dInfo,
-                                                      batchCount),
+                                                      batch_count),
                           HIPBLAS_STATUS_INVALID_VALUE);
     expectedInfo = -6;
     unit_check_general(1, 1, 1, &expectedInfo, &info);
@@ -168,7 +189,7 @@ void testing_gels_strided_batched_bad_arg(const Arguments& arg)
                                                       strideB,
                                                       &info,
                                                       dInfo,
-                                                      batchCount),
+                                                      batch_count),
                           HIPBLAS_STATUS_INVALID_VALUE);
     expectedInfo = -8;
     unit_check_general(1, 1, 1, &expectedInfo, &info);
@@ -187,7 +208,7 @@ void testing_gels_strided_batched_bad_arg(const Arguments& arg)
                                                       strideB,
                                                       &info,
                                                       dInfo,
-                                                      batchCount),
+                                                      batch_count),
                           HIPBLAS_STATUS_INVALID_VALUE);
     expectedInfo = -9;
     unit_check_general(1, 1, 1, &expectedInfo, &info);
@@ -205,7 +226,7 @@ void testing_gels_strided_batched_bad_arg(const Arguments& arg)
                                                       strideB,
                                                       &info,
                                                       dInfo,
-                                                      batchCount),
+                                                      batch_count),
                           HIPBLAS_STATUS_INVALID_VALUE);
     expectedInfo = -9;
     unit_check_general(1, 1, 1, &expectedInfo, &info);
@@ -223,7 +244,7 @@ void testing_gels_strided_batched_bad_arg(const Arguments& arg)
                                                       strideB,
                                                       &info,
                                                       nullptr,
-                                                      batchCount),
+                                                      batch_count),
                           HIPBLAS_STATUS_INVALID_VALUE);
     expectedInfo = -12;
     unit_check_general(1, 1, 1, &expectedInfo, &info);
@@ -249,7 +270,7 @@ void testing_gels_strided_batched_bad_arg(const Arguments& arg)
                                                       strideB,
                                                       &info,
                                                       dInfo,
-                                                      batchCount),
+                                                      batch_count),
                           HIPBLAS_STATUS_SUCCESS);
     expectedInfo = 0;
     unit_check_general(1, 1, 1, &expectedInfo, &info);
@@ -267,7 +288,7 @@ void testing_gels_strided_batched_bad_arg(const Arguments& arg)
                                                       strideB,
                                                       &info,
                                                       dInfo,
-                                                      batchCount),
+                                                      batch_count),
                           HIPBLAS_STATUS_SUCCESS);
     expectedInfo = 0;
     unit_check_general(1, 1, 1, &expectedInfo, &info);
@@ -286,7 +307,7 @@ void testing_gels_strided_batched_bad_arg(const Arguments& arg)
                                                       strideB,
                                                       &info,
                                                       dInfo,
-                                                      batchCount),
+                                                      batch_count),
                           HIPBLAS_STATUS_SUCCESS);
     expectedInfo = 0;
     unit_check_general(1, 1, 1, &expectedInfo, &info);
@@ -305,12 +326,12 @@ void testing_gels_strided_batched_bad_arg(const Arguments& arg)
                                                       strideB,
                                                       &info,
                                                       dInfo,
-                                                      batchCount),
+                                                      batch_count),
                           HIPBLAS_STATUS_SUCCESS);
     expectedInfo = 0;
     unit_check_general(1, 1, 1, &expectedInfo, &info);
 
-    // if batchCount == 0, dInfo can be nullptr
+    // if batch_count == 0, dInfo can be nullptr
     EXPECT_HIPBLAS_STATUS(
         hipblasGelsStridedBatchedFn(
             handle, opN, M, N, nrhs, dA, lda, strideA, dB, ldb, strideB, &info, nullptr, 0),
@@ -334,7 +355,7 @@ void testing_gels_strided_batched(const Arguments& arg)
     int    lda         = arg.lda;
     int    ldb         = arg.ldb;
     double strideScale = arg.stride_scale;
-    int    batchCount  = arg.batch_count;
+    int    batch_count = arg.batch_count;
 
     if(is_complex<T> && transc == 'T')
         transc = 'C';
@@ -346,60 +367,69 @@ void testing_gels_strided_batched(const Arguments& arg)
 
     hipblasStride strideA = size_t(lda) * N * strideScale;
     hipblasStride strideB = size_t(ldb) * nrhs * strideScale;
-    size_t        A_size  = strideA * batchCount;
-    size_t        B_size  = strideB * batchCount;
 
     // Check to prevent memory allocation error
-    if(M < 0 || N < 0 || nrhs < 0 || lda < M || ldb < M || ldb < N || batchCount < 0)
+    if(M < 0 || N < 0 || nrhs < 0 || lda < M || ldb < M || ldb < N || batch_count < 0)
     {
         return;
     }
-    if(batchCount == 0)
+    if(batch_count == 0)
     {
         return;
     }
 
     // Naming: dK is in GPU (device) memory. hK is in CPU (host) memory
-    host_vector<T>   hA(A_size);
-    host_vector<T>   hB(B_size);
-    host_vector<T>   hB_res(B_size);
-    host_vector<int> info_res(batchCount);
-    host_vector<int> info(batchCount);
-    int              info_input(-1);
+    host_strided_batch_matrix<T> hA(M, N, lda, strideA, batch_count);
+    host_strided_batch_matrix<T> hB(M, nrhs, ldb, strideB, batch_count);
+    host_strided_batch_matrix<T> hB_res(M, nrhs, ldb, strideB, batch_count);
+    host_vector<int>             info_res(batch_count);
+    host_vector<int>             info(batch_count);
+    int                          info_input(-1);
 
-    device_vector<T>   dA(A_size);
-    device_vector<T>   dB(B_size);
-    device_vector<int> dInfo(batchCount);
+    // Check host memory allocation
+    CHECK_HIP_ERROR(hA.memcheck());
+    CHECK_HIP_ERROR(hB.memcheck());
+    CHECK_HIP_ERROR(hB_res.memcheck());
+    CHECK_HIP_ERROR(info_res.memcheck());
+    CHECK_HIP_ERROR(info.memcheck());
+
+    // Allocate device memory
+    device_strided_batch_matrix<T> dA(M, N, lda, strideA, batch_count);
+    device_strided_batch_matrix<T> dB(M, nrhs, ldb, strideB, batch_count);
+    device_vector<int>             dInfo(batch_count);
+
+    // Check device memory allocation
+    CHECK_DEVICE_ALLOCATION(dA.memcheck());
+    CHECK_DEVICE_ALLOCATION(dB.memcheck());
+    CHECK_DEVICE_ALLOCATION(dInfo.memcheck());
 
     double             gpu_time_used, hipblas_error;
     hipblasLocalHandle handle(arg);
 
     // Initial hA, hB, hX on CPU
-    srand(1);
-    hipblas_init<T>(hA, true);
-    hipblas_init<T>(hB);
-    for(int b = 0; b < batchCount; b++)
-    {
-        T* hAb = hA.data() + b * strideA;
+    hipblas_init_matrix(hA, arg, hipblas_client_never_set_nan, hipblas_general_matrix, true);
+    hipblas_init_matrix(hB, arg, hipblas_client_never_set_nan, hipblas_general_matrix, false, true);
 
+    for(int b = 0; b < batch_count; b++)
+    {
         // scale A to avoid singularities
         for(int i = 0; i < N; i++)
         {
             for(int j = 0; j < N; j++)
             {
                 if(i == j)
-                    hAb[i + j * lda] += 400;
+                    hA[b][i + j * lda] += 400;
                 else
-                    hAb[i + j * lda] -= 4;
+                    hA[b][i + j * lda] -= 4;
             }
         }
     }
 
-    hB_res = hB;
+    hB_res.copy_from(hB);
 
     // Copy data from CPU to device
-    CHECK_HIP_ERROR(hipMemcpy(dA, hA, A_size * sizeof(T), hipMemcpyHostToDevice));
-    CHECK_HIP_ERROR(hipMemcpy(dB, hB, B_size * sizeof(T), hipMemcpyHostToDevice));
+    CHECK_HIP_ERROR(dA.transfer_from(hA));
+    CHECK_HIP_ERROR(dB.transfer_from(hB));
 
     if(arg.unit_check || arg.norm_check)
     {
@@ -419,12 +449,12 @@ void testing_gels_strided_batched(const Arguments& arg)
                                                         strideB,
                                                         &info_input,
                                                         dInfo,
-                                                        batchCount));
+                                                        batch_count));
 
         // copy output from device to CPU
-        CHECK_HIP_ERROR(hipMemcpy(hB_res, dB, B_size * sizeof(T), hipMemcpyDeviceToHost));
+        CHECK_HIP_ERROR(hB_res.transfer_from(dB));
         CHECK_HIP_ERROR(
-            hipMemcpy(info_res.data(), dInfo, sizeof(int) * batchCount, hipMemcpyDeviceToHost));
+            hipMemcpy(info_res.data(), dInfo, sizeof(int) * batch_count, hipMemcpyDeviceToHost));
 
         /* =====================================================================
            CPU LAPACK
@@ -432,26 +462,17 @@ void testing_gels_strided_batched(const Arguments& arg)
         int            sizeW = std::max(1, std::min(M, N) + std::max(std::min(M, N), nrhs));
         host_vector<T> hW(sizeW);
 
-        for(int b = 0; b < batchCount; b++)
+        for(int b = 0; b < batch_count; b++)
         {
-            info[b] = ref_gels(transc,
-                               M,
-                               N,
-                               nrhs,
-                               hA.data() + b * strideA,
-                               lda,
-                               hB.data() + b * strideB,
-                               ldb,
-                               hW.data(),
-                               sizeW);
+            info[b] = ref_gels(transc, M, N, nrhs, hA[b], lda, hB[b], ldb, hW.data(), sizeW);
         }
 
         hipblas_error = norm_check_general<T>(
-            'F', std::max(M, N), nrhs, ldb, strideB, hB.data(), hB_res.data(), batchCount);
+            'F', std::max(M, N), nrhs, ldb, strideB, hB.data(), hB_res.data(), batch_count);
 
         if(info_input != 0)
             hipblas_error += 1.0;
-        for(int b = 0; b < batchCount; b++)
+        for(int b = 0; b < batch_count; b++)
         {
             if(info[b] != info_res[b])
                 hipblas_error += 1.0;
@@ -492,7 +513,7 @@ void testing_gels_strided_batched(const Arguments& arg)
                                                             strideB,
                                                             &info_input,
                                                             dInfo,
-                                                            batchCount));
+                                                            batch_count));
         }
         gpu_time_used = get_time_us_sync(stream) - gpu_time_used;
 
